# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.environments import environments_pb2 as scalekit_dot_v1_dot_environments_dot_environments__pb2


class EnvironmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnvironment = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CreateEnvironment',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentResponse.FromString,
                )
        self.UpdateEnvironment = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateEnvironment',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.FromString,
                )
        self.UpdateEnvironmentDomain = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentDomain',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetEnvironment',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.FromString,
                )
        self.ListEnvironment = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/ListEnvironment',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsResponse.FromString,
                )
        self.DeleteEnvironment = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/DeleteEnvironment',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.DeleteEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRequiredDNSRecords = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetRequiredDNSRecords',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsResponse.FromString,
                )
        self.VerifyDNSRecords = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/VerifyDNSRecords',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateCustomDomain = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CreateCustomDomain',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainResponse.FromString,
                )
        self.CheckCustomDomainStatus = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CheckCustomDomainStatus',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.FromString,
                )
        self.GenerateNewSamlCertificate = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GenerateNewSamlCertificate',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateResponse.FromString,
                )
        self.UpdatePortalCustomization = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdatePortalCustomization',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationResponse.FromString,
                )
        self.GetPortalCustomization = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetPortalCustomization',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationResponse.FromString,
                )
        self.CreateAssetUploadURL = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CreateAssetUploadURL',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlResponse.FromString,
                )
        self.UpdateFeatures = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateFeatures',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateFeaturesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.FromString,
                )
        self.EnableFSAFeature = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/EnableFSAFeature',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFSAFeatureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.EnableFeature = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/EnableFeature',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFeatureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisableFeature = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/DisableFeature',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.DisableFeatureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetFeatures = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetFeatures',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.FromString,
                )
        self.CreateEnvironmentSessionSettings = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CreateEnvironmentSessionSettings',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsResponse.FromString,
                )
        self.CreateEnvironmentUserManagement = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/CreateEnvironmentUserManagement',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementResponse.FromString,
                )
        self.GetEnvironmentSessionSettings = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetEnvironmentSessionSettings',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsResponse.FromString,
                )
        self.GetEnvironmentUserManagement = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetEnvironmentUserManagement',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementResponse.FromString,
                )
        self.UpdateEnvironmentSessionSettings = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentSessionSettings',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsResponse.FromString,
                )
        self.UpdateEnvironmentUserManagement = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentUserManagement',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementResponse.FromString,
                )
        self.GetContext = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetContext',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextResponse.FromString,
                )
        self.UpdateContext = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/UpdateContext',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateContextRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetCurrentSession = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetCurrentSession',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionResponse.FromString,
                )
        self.GetScalekitResources = channel.unary_unary(
                '/scalekit.v1.environments.EnvironmentService/GetScalekitResources',
                request_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceResponse.FromString,
                )


class EnvironmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRequiredDNSRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyDNSRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCustomDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckCustomDomainStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateNewSamlCertificate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePortalCustomization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPortalCustomization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAssetUploadURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableFSAFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironmentSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironmentUserManagement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentUserManagement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentSessionSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentUserManagement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateContext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScalekitResources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EnvironmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentResponse.SerializeToString,
            ),
            'UpdateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironment,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.SerializeToString,
            ),
            'UpdateEnvironmentDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentDomain,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.SerializeToString,
            ),
            'ListEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironment,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'DeleteEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironment,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.DeleteEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRequiredDNSRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRequiredDNSRecords,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsResponse.SerializeToString,
            ),
            'VerifyDNSRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyDNSRecords,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateCustomDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCustomDomain,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainResponse.SerializeToString,
            ),
            'CheckCustomDomainStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckCustomDomainStatus,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.SerializeToString,
            ),
            'GenerateNewSamlCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateNewSamlCertificate,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateResponse.SerializeToString,
            ),
            'UpdatePortalCustomization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePortalCustomization,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationResponse.SerializeToString,
            ),
            'GetPortalCustomization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPortalCustomization,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationResponse.SerializeToString,
            ),
            'CreateAssetUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAssetUploadURL,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlResponse.SerializeToString,
            ),
            'UpdateFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatures,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateFeaturesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.SerializeToString,
            ),
            'EnableFSAFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableFSAFeature,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFSAFeatureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'EnableFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableFeature,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFeatureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisableFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableFeature,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.DisableFeatureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatures,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.SerializeToString,
            ),
            'CreateEnvironmentSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironmentSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsResponse.SerializeToString,
            ),
            'CreateEnvironmentUserManagement': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironmentUserManagement,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementResponse.SerializeToString,
            ),
            'GetEnvironmentSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsResponse.SerializeToString,
            ),
            'GetEnvironmentUserManagement': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentUserManagement,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementResponse.SerializeToString,
            ),
            'UpdateEnvironmentSessionSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentSessionSettings,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsResponse.SerializeToString,
            ),
            'UpdateEnvironmentUserManagement': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentUserManagement,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementResponse.SerializeToString,
            ),
            'GetContext': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContext,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextResponse.SerializeToString,
            ),
            'UpdateContext': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateContext,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateContextRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetCurrentSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentSession,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionResponse.SerializeToString,
            ),
            'GetScalekitResources': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScalekitResources,
                    request_deserializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.environments.EnvironmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EnvironmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CreateEnvironment',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateEnvironment',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentDomain',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetEnvironment',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/ListEnvironment',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/DeleteEnvironment',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.DeleteEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRequiredDNSRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetRequiredDNSRecords',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyDNSRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/VerifyDNSRecords',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetDNSRecordsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCustomDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CreateCustomDomain',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateCustomDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckCustomDomainStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CheckCustomDomainStatus',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateNewSamlCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GenerateNewSamlCertificate',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GenerateSamlCertificateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePortalCustomization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdatePortalCustomization',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdatePortalCustomizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPortalCustomization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetPortalCustomization',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetPortalCustomizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAssetUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CreateAssetUploadURL',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateAssetUploadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateFeatures',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateFeaturesRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableFSAFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/EnableFSAFeature',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFSAFeatureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/EnableFeature',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.EnableFeatureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/DisableFeature',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.DisableFeatureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetFeatures',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEnvironmentSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CreateEnvironmentSessionSettings',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEnvironmentUserManagement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/CreateEnvironmentUserManagement',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.CreateEnvironmentUserManagementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetEnvironmentSessionSettings',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentUserManagement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetEnvironmentUserManagement',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetEnvironmentUserManagementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentSessionSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentSessionSettings',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentSessionSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentUserManagement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateEnvironmentUserManagement',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateEnvironmentUserManagementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetContext',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetContextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateContext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/UpdateContext',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.UpdateContextRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurrentSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetCurrentSession',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.GetCurrentSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScalekitResources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.environments.EnvironmentService/GetScalekitResources',
            scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceRequest.SerializeToString,
            scalekit_dot_v1_dot_environments_dot_environments__pb2.ScalekitResourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from pydantic import BaseModel


class DeleteConnectedAccountResponse(BaseModel):
    """Delete connected account response with one-to-one mapping to proto DeleteConnectedAccountResponse"""

    @classmethod
    def from_proto(cls, proto_response) -> 'DeleteConnectedAccountResponse':
        """
        Create DeleteConnectedAccountResponse from protobuf DeleteConnectedAccountResponse
        
        :param proto_response: The protobuf DeleteConnectedAccountResponse object
        :type proto_response: DeleteConnectedAccountResponse (from connected_accounts_pb2)
        
        :returns:
            DeleteConnectedAccountResponse instance
        """

        # Since the DeleteConnectedAccountResponse does not have any fields
        return cls()

    def to_dict(self) -> dict:
        """
        Convert to dictionary representation
        
        :returns:
            Dictionary representation of the response
        """
        return {}

    class Config:
        """Pydantic configuration"""
        validate_assignment = True


from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FSADataType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FSA_DATA_TYPE_UNSPECIFIED: _ClassVar[FSADataType]
    FSA_DATA_TYPE_CONNECTION: _ClassVar[FSADataType]
    FSA_DATA_TYPE_SESSION: _ClassVar[FSADataType]
    FSA_DATA_TYPE_USER_MANAGEMENT: _ClassVar[FSADataType]
FSA_DATA_TYPE_UNSPECIFIED: FSADataType
FSA_DATA_TYPE_CONNECTION: FSADataType
FSA_DATA_TYPE_SESSION: FSADataType
FSA_DATA_TYPE_USER_MANAGEMENT: FSADataType

class MigrationServiceResponse(_message.Message):
    __slots__ = ("success_environments", "failed_environments")
    SUCCESS_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    FAILED_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    success_environments: int
    failed_environments: int
    def __init__(self, success_environments: _Optional[int] = ..., failed_environments: _Optional[int] = ...) -> None: ...

class MigrationSAMLRequest(_message.Message):
    __slots__ = ("environment_ids", "batch_size")
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    environment_ids: _containers.RepeatedScalarFieldContainer[int]
    batch_size: int
    def __init__(self, environment_ids: _Optional[_Iterable[int]] = ..., batch_size: _Optional[int] = ...) -> None: ...

class MigrateFSARequest(_message.Message):
    __slots__ = ("environment_ids", "data_type", "batch_size")
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    environment_ids: _containers.RepeatedScalarFieldContainer[int]
    data_type: FSADataType
    batch_size: int
    def __init__(self, environment_ids: _Optional[_Iterable[int]] = ..., data_type: _Optional[_Union[FSADataType, str]] = ..., batch_size: _Optional[int] = ...) -> None: ...

class MigrationFSAResponse(_message.Message):
    __slots__ = ("success_environments", "failed_environments")
    SUCCESS_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    FAILED_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    success_environments: int
    failed_environments: int
    def __init__(self, success_environments: _Optional[int] = ..., failed_environments: _Optional[int] = ...) -> None: ...

class MigrationSAMLResponse(_message.Message):
    __slots__ = ("success_environments", "failed_environments")
    SUCCESS_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    FAILED_ENVIRONMENTS_FIELD_NUMBER: _ClassVar[int]
    success_environments: int
    failed_environments: int
    def __init__(self, success_environments: _Optional[int] = ..., failed_environments: _Optional[int] = ...) -> None: ...
